@@ -455,6 +455,75 @@ empathy_account_settings_get_password_cb (GObject *source,
   g_signal_emit (self, signals[PASSWORD_RETRIEVED], 0);
 }
 
+static void
+empathy_account_settings_migrate_password_cb (GObject *source,
+    GAsyncResult *result,
+    gpointer user_data)
+{
+  TpAccount *account = TP_ACCOUNT (source);
+  GError *error = NULL;
+  EmpathyAccountSettings *self = user_data;
+  EmpathyAccountSettingsPriv *priv = GET_PRIV (self);
+  GHashTable *empty;
+  const gchar *unset[] = { "password", NULL };
+
+  if (!empathy_keyring_set_password_finish (account, result, &error))
+    {
+      DEBUG ("Failed to set password: %s", error->message);
+      g_clear_error (&error);
+      return;
+    }
+
+  /* Now clear the password MC has stored. */
+  empty = tp_asv_new (NULL, NULL);
+  tp_account_update_parameters_async (priv->account,
+      empty, unset, NULL, NULL);
+
+  g_hash_table_remove (priv->parameters, "password");
+
+  g_hash_table_unref (empty);
+}
+
+static void
+empathy_account_settings_try_migrating_password (EmpathyAccountSettings *self)
+{
+  EmpathyAccountSettingsPriv *priv = GET_PRIV (self);
+  const GValue *v;
+  const gchar *password;
+
+  if (!priv->supports_sasl || empathy_account_settings_get (
+          self, "password") == NULL)
+    return;
+
+  /* mission-control still has our password, although the CM
+   * supports SASL. Let's try migrating it. */
+
+  DEBUG ("Trying to migrate password parameter from MC to the "
+      "keyring ourselves for account %s",
+      tp_account_get_path_suffix (priv->account));
+
+  v = empathy_account_settings_get (self, "password");
+
+  /* I can't imagine why this would fail. */
+  if (!G_VALUE_HOLDS_STRING (v))
+    return;
+
+  password = g_value_get_string (v);
+
+  if (EMP_STR_EMPTY (password))
+    return;
+
+  empathy_keyring_set_password_async (priv->account, password,
+      empathy_account_settings_migrate_password_cb, self);
+
+  /* We don't want to request the password again, we
+   * already know it. */
+  priv->password_requested = TRUE;
+
+  priv->password = g_strdup (password);
+  priv->password_original = g_strdup (password);
+}
+
 static void
 empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
 {
@@ -542,6 +611,10 @@ empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
         }
     }
 
+  /* NOTE: When removing MC migration code, remove this call, and the
+   * function it's calling. That's it. */
+  empathy_account_settings_try_migrating_password (self);
+
   /* priv->account won't be a proper account if it's the account
    * assistant showing this widget. */
   if (priv->supports_sasl && !priv->password_requested
