@@ -73,12 +73,10 @@ typedef struct
 } EmpathyTpCallStream;
 
 GType empathy_tp_call_get_type (void) G_GNUC_CONST;
-EmpathyTpCall *empathy_tp_call_new (TpChannel *channel);
+EmpathyTpCall *empathy_tp_call_new (TpAccount *account,
+    TpChannel *channel);
 void empathy_tp_call_close (EmpathyTpCall *call);
 
-void empathy_tp_call_to (EmpathyTpCall *call, EmpathyContact *contact,
-  gboolean audio, gboolean video);
-
 void empathy_tp_call_accept_incoming_call (EmpathyTpCall *call);
 void empathy_tp_call_request_video_stream_direction (EmpathyTpCall *call,
     gboolean is_sending);
@@ -96,6 +94,8 @@ void empathy_tp_call_leave (EmpathyTpCall *self);
 
 EmpathyTpCallStatus empathy_tp_call_get_status (EmpathyTpCall *self);
 
+TpAccount * empathy_tp_call_get_account (EmpathyTpCall *self);
+
 G_END_DECLS
 
 #endif /* __EMPATHY_TP_CALL_H__ */
