@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2007 Imendio AB
- * Copyright (C) 2007-2011 Collabora Ltd.
+ * Copyright (C) 2007-2008 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -50,6 +50,7 @@
 #include "empathy-individual-manager.h"
 #include "empathy-dispatcher.h"
 #include "empathy-idle.h"
+#include "empathy-tp-call.h"
 #include "empathy-tp-contact-factory.h"
 
 #include <extensions/extensions.h>
@@ -379,8 +380,6 @@ create_errors_to_message_hash (void)
 		_("The length of the server certificate, or the depth of the "
 		"server certificate chain, exceed the limits imposed by the "
 		"cryptography library"));
-	g_hash_table_insert (errors, TP_ERROR_STR_SOFTWARE_UPGRADE_REQUIRED,
-		_("Your software is too old"));
 
 	return errors;
 }
@@ -540,15 +539,13 @@ empathy_protocol_name_to_display_name (const gchar *proto_name)
     gboolean translated;
   } names[] = {
     { "jabber", "Jabber", FALSE },
-    { "gtalk", "Google Talk", FALSE },
-    { "msn", "Windows Live (MSN)", FALSE, },
+    { "msn", "MSN", FALSE, },
     { "local-xmpp", N_("People Nearby"), TRUE },
     { "irc", "IRC", FALSE },
     { "icq", "ICQ", FALSE },
     { "aim", "AIM", FALSE },
     { "yahoo", "Yahoo!", FALSE },
     { "yahoojp", N_("Yahoo! Japan"), TRUE },
-    { "facebook", N_("Facebook Chat"), TRUE },
     { "groupwise", "GroupWise", FALSE },
     { "sip", "SIP", FALSE },
     { NULL, NULL }
@@ -559,13 +556,41 @@ empathy_protocol_name_to_display_name (const gchar *proto_name)
       if (!tp_strdiff (proto_name, names[i].proto))
         {
           if (names[i].translated)
-            return _(names[i].display);
+            return gettext (names[i].display);
           else
             return names[i].display;
         }
     }
 
-  return NULL;
+  return proto_name;
+}
+
+const char *
+empathy_service_name_to_display_name (const gchar *service_name)
+{
+  int i;
+  static struct {
+    const gchar *service;
+    const gchar *display;
+    gboolean translated;
+  } names[] = {
+    { "google-talk", N_("Google Talk"), FALSE },
+    { "facebook", N_("Facebook Chat"), TRUE },
+    { NULL, NULL }
+  };
+
+  for (i = 0; names[i].service != NULL; i++)
+    {
+      if (!tp_strdiff (service_name, names[i].service))
+        {
+          if (names[i].translated)
+            return gettext (names[i].display);
+          else
+            return names[i].display;
+        }
+    }
+
+  return service_name;
 }
 
 /* Note: this function depends on the account manager having its core feature
@@ -698,7 +723,7 @@ empathy_folks_individual_contains_contact (FolksIndividual *individual)
   personas = folks_individual_get_personas (individual);
   for (l = personas; l != NULL; l = l->next)
     {
-      if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (l->data)))
+      if (TPF_IS_PERSONA (l->data))
         return (tpf_persona_get_contact (TPF_PERSONA (l->data)) != NULL);
     }
 
@@ -725,7 +750,7 @@ empathy_contact_dup_from_folks_individual (FolksIndividual *individual)
     {
       TpfPersona *persona = l->data;
 
-      if (empathy_folks_persona_is_interesting (FOLKS_PERSONA (persona)))
+      if (TPF_IS_PERSONA (persona))
         {
           TpContact *tp_contact;
 
@@ -740,27 +765,89 @@ empathy_contact_dup_from_folks_individual (FolksIndividual *individual)
 
 TpChannelGroupChangeReason
 tp_channel_group_change_reason_from_folks_groups_change_reason (
-    FolksGroupDetailsChangeReason reason)
+    FolksGroupableChangeReason reason)
 {
   return (TpChannelGroupChangeReason) reason;
 }
 
-gboolean
-empathy_folks_persona_is_interesting (FolksPersona *persona)
+TpfPersonaStore *
+empathy_get_persona_store_for_connection (TpConnection *connection)
 {
-  /* We're not interested in non-Telepathy personas */
-  if (!TPF_IS_PERSONA (persona))
-    return FALSE;
+  FolksBackendStore *backend_store;
+  FolksBackend *backend;
+  TpfPersonaStore *result = NULL;
 
-  /* We're not interested in user personas which haven't been added to the
-   * contact list (see bgo#637151). */
-  if (folks_persona_get_is_user (persona) &&
-      !tpf_persona_get_is_in_contact_list (TPF_PERSONA (persona)))
+  backend_store = folks_backend_store_dup ();
+  backend = folks_backend_store_get_backend_by_name (backend_store,
+      "telepathy");
+  if (backend != NULL)
     {
-      return FALSE;
+      GHashTable *stores_hash;
+      GList *stores, *l;
+
+      stores_hash = folks_backend_get_persona_stores (backend);
+      stores = g_hash_table_get_values (stores_hash);
+      for (l = stores; l != NULL && result == NULL; l = l->next)
+        {
+          TpfPersonaStore *persona_store = TPF_PERSONA_STORE (l->data);
+          TpAccount *account;
+          TpConnection *conn_cur;
+
+          account = tpf_persona_store_get_account (persona_store);
+          conn_cur = tp_account_get_connection (account);
+          if (conn_cur == connection)
+            result = persona_store;
+        }
+
+      g_list_free (stores);
     }
 
-  return TRUE;
+  g_object_unref (backend);
+  g_object_unref (backend_store);
+
+  return result;
+}
+
+gboolean
+empathy_connection_can_add_personas (TpConnection *connection)
+{
+  FolksPersonaStore *persona_store;
+
+  g_return_val_if_fail (TP_IS_CONNECTION (connection), FALSE);
+
+  persona_store = FOLKS_PERSONA_STORE (
+      empathy_get_persona_store_for_connection (connection));
+
+  return (folks_persona_store_get_can_add_personas (persona_store) ==
+      FOLKS_MAYBE_BOOL_TRUE);
+}
+
+gboolean
+empathy_connection_can_alias_personas (TpConnection *connection)
+{
+  FolksPersonaStore *persona_store;
+
+  g_return_val_if_fail (TP_IS_CONNECTION (connection), FALSE);
+
+  persona_store = FOLKS_PERSONA_STORE (
+      empathy_get_persona_store_for_connection (connection));
+
+  return (folks_persona_store_get_can_alias_personas (persona_store) ==
+      FOLKS_MAYBE_BOOL_TRUE);
+}
+
+gboolean
+empathy_connection_can_group_personas (TpConnection *connection)
+{
+  FolksPersonaStore *persona_store;
+
+  g_return_val_if_fail (TP_IS_CONNECTION (connection), FALSE);
+
+  persona_store = FOLKS_PERSONA_STORE (
+      empathy_get_persona_store_for_connection (connection));
+
+  return (folks_persona_store_get_can_group_personas (persona_store) ==
+      FOLKS_MAYBE_BOOL_TRUE);
 }
 
 gchar *
