@@ -1502,9 +1502,9 @@ accounts_dialog_treeview_button_press_event_cb (GtkTreeView *view,
     EmpathyAccountsDialog *dialog)
 {
   EmpathyAccountsDialogPriv *priv = GET_PRIV (dialog);
-  TpAccount *account;
-  GtkTreeModel *model;
-  GtkTreePath *path;
+  TpAccount *account = NULL;
+  GtkTreeModel *model = NULL;
+  GtkTreePath *path = NULL;
   GtkTreeIter iter;
   GtkWidget *menu;
   GtkWidget *item_enable, *item_disable;
@@ -1543,8 +1543,10 @@ accounts_dialog_treeview_button_press_event_cb (GtkTreeView *view,
   /* Menu items: to enabled/disable the account */
   item_enable = gtk_image_menu_item_new_with_mnemonic (_("_Enable"));
   item_disable = gtk_image_menu_item_new_with_mnemonic (_("_Disable"));
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item_enable), image_enable);
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item_disable), image_disable);
+  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item_enable),
+      image_enable);
+  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item_disable),
+      image_disable);
 
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item_enable);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item_disable);
@@ -1573,7 +1575,7 @@ accounts_dialog_treeview_button_press_event_cb (GtkTreeView *view,
 
 finally:
   tp_clear_object (&account);
-  tp_clear_pointer (&path, gtk_tree_path_free);
+  gtk_tree_path_free (path);
 
   return FALSE;
 }
